@@ -32,17 +32,17 @@ describe Compiler::GrammarCompiler do
   specify "compilation of a single file to a default file name" do
     src_copy = "#{@tmpdir}/test_grammar.treetop"
     File.open(source_path_with_treetop_extension) { |f| File.open(src_copy,'w'){|o|o.write(f.read)} }
-    File.exists?(target_path).should be_falsey
+    File.exist?(target_path).should be_falsey
     compiler.compile(src_copy)
-    File.exists?(target_path).should be_truthy
+    File.exist?(target_path).should be_truthy
     require target_path
     Test::GrammarParser.new.parse('foo').should_not be_nil
   end
 
   specify "compilation of a single file to an explicit file name" do
-    File.exists?(alternate_target_path).should be_falsy
+    File.exist?(alternate_target_path).should be_falsey
     compiler.compile(source_path_with_treetop_extension, alternate_target_path)
-    File.exists?(alternate_target_path).should be_truthy
+    File.exist?(alternate_target_path).should be_truthy
     require alternate_target_path
     Test::GrammarParser.new.parse('foo').should_not be_nil
   end
@@ -105,9 +105,9 @@ describe Compiler::GrammarCompiler do
   end
 
   def delete_target_files
-    File.delete(target_path) if File.exists?(target_path)
-    File.delete(@target_path_with_do) if File.exists?(@target_path_with_do)
-    File.delete(alternate_target_path) if File.exists?(alternate_target_path)
+    File.delete(target_path) if File.exist?(target_path)
+    File.delete(@target_path_with_do) if File.exist?(@target_path_with_do)
+    File.delete(alternate_target_path) if File.exist?(alternate_target_path)
   end
 end
 
